@@ -1401,9 +1401,8 @@ where
 mod test {
   use super::PgHammerfestStore;
   use crate::test::TestApi;
-  use chrono::{TimeZone, Utc};
   use etwin_core::clock::VirtualClock;
-  use etwin_core::core::Secret;
+  use etwin_core::core::{Instant, Secret};
   use etwin_core::hammerfest::HammerfestStore;
   use etwin_core::uuid::Uuid4Generator;
   use etwin_db_schema::force_create_latest;
@@ -1443,7 +1442,7 @@ mod test {
       .unwrap();
     let database = Arc::new(database);
 
-    let clock = Arc::new(VirtualClock::new(Utc.ymd(2020, 1, 1).and_hms(0, 0, 0)));
+    let clock = Arc::new(VirtualClock::new(Instant::ymd_hms(2020, 1, 1, 0, 0, 0)));
     let uuid_generator = Arc::new(Uuid4Generator);
     let database_secret = Secret::new("dev_secret".to_string());
     let hammerfest_store: Arc<dyn HammerfestStore> = Arc::new(
